#!/usr/bin/python3
#
# Copyright (C) 2012, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-test-cases.
#
# ubuntu-test-cases is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-test-cases is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-test-cases.  If not, see
# <http://www.gnu.org/licenses/>.

"""Machine ID file exists and it was created recently."""

import logging
import os.path
import unittest
import time


class MachineIdTest(unittest.TestCase):
    MACHINE_ID_FILE = '/etc/machine-id'
    MACHINE_ID_FILE_FALLBACK = '/var/lib/dbus/machine-id'

    # Expected age of the file is 30 minutes (1800 seconds) which is an
    # arbitrary value sane in VM with low resources as well as bare metal
    # environments
    EXPECTED_AGE = 1800

    def test_machine_id(self):
        """Machine Id is there and log content and age."""
        logging.info('Checking that machine id file {!r} or {!r} exists...'
                     .format(self.MACHINE_ID_FILE,
                             self.MACHINE_ID_FILE_FALLBACK))

        logging.info('Reading file...')
        try:
            with open(self.MACHINE_ID_FILE) as f:
                machine_id = f.read().rstrip()
                logging.info('The machine id is {!r}'.format(machine_id))
        except IOError:
            logging.info('Couldn\'t open {!r}, trying {!r}'
                         .format(self.MACHINE_ID_FILE,
                                 self.MACHINE_ID_FILE_FALLBACK))
            with open(self.MACHINE_ID_FILE_FALLBACK) as f:
                self.MACHINE_ID_FILE = self.MACHINE_ID_FILE_FALLBACK
                machine_id = f.read().rstrip()
                logging.info('The machine id is {!r}'.format(machine_id))

        logging.info('Getting last modification time...')
        mtime = os.path.getmtime(self.MACHINE_ID_FILE)
        mtime_struct = time.gmtime(mtime)
        mtime_str = time.strftime('%c', mtime_struct)
        logging.info('Last modification time: {} ({})'
                     .format(mtime_str, mtime))
        now = time.time()
        age = now - mtime
        logging.info('Machine id is {} seconds old'.format(age))
        self.assertLess(age, self.EXPECTED_AGE)

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
